import { Body, Controller, Get, Post, UseGuards } from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import { ApiBearerAuth, ApiBody, ApiOperation, ApiTags } from '@nestjs/swagger';
import { Serealize } from '../interceptors/serialize.interceptor';
import { TipoUsuarioService } from './tipo-usuario.service';
import { CreateTipoUsuarioDto } from './dto/input/create.dto';
import { TipoUsuarioOutputDto } from './dto/output/tipo-usuario.dto';

@Controller('tipo-usuario')
@ApiTags('tipo-usuario')
export class TipoUsuarioController {
  constructor(private tipoUsuarioService: TipoUsuarioService) {}

  @Post()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({ description: 'Endpoint que crea un nuevo tipo de usuario.' })
  @ApiBearerAuth('jwt')
  @ApiBody({
    description: 'Es obligatorio mandar el campo tipo_usuario.',
    examples: { ejemplo: { value: { tipo_usuario: '' } } },
  })
  create(@Body() body: CreateTipoUsuarioDto) {
    return this.tipoUsuarioService.create(body.tipo_usuario);
  }

  @Serealize(TipoUsuarioOutputDto)
  @Get()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description: 'Endpoint que retorna todos los tipos de usuario.',
  })
  @ApiBearerAuth('jwt')
  get() {
    return this.tipoUsuarioService.findAll();
  }

  @Serealize(TipoUsuarioOutputDto)
  @Get('operador')
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description:
      'Endpoint que retorna todos los tipos de usuario que debe ver un operador.',
  })
  @ApiBearerAuth('jwt')
  operador() {
    return this.tipoUsuarioService.findAll('operador');
  }
}
